package com.autentia.adictos.hs.test;

import java.util.List;

import junit.framework.Assert;

import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

import com.autentia.adictos.hs.dao.DaoFactory;
import com.autentia.adictos.hs.dao.HibernateDaoImpl;
import com.autentia.adictos.hs.model.Noticia;
import com.autentia.adictos.hs.test.utils.DataGenerator;

public class SearchNoticiasTest {

	public static final String[] whereToSearch = { "titular", "entradilla", "cuerpo", "autor.nombre",
			"autor.apellidos", "fechaPublicacion" };

	@BeforeClass
	public static void startUp() {
		DaoFactory.init();
		DataGenerator.createData();

	}

	@AfterClass
	public static void tearDown() {
		DaoFactory.close();
	}

	@Test
	public void test1HayNoticias() {
		HibernateDaoImpl dao = DaoFactory.getDao();
		List<Noticia> noticias = dao.loadAll(Noticia.class);

		Assert.assertTrue("El número de noticias total no coincide", noticias.size() == 3);

	}

	/*
	 * Búsqueda normal por palabras. Buscamos las palabras aumentar y lograr, que no están pero si aumentó y logró
	 */
	@Test
	public void test2BusquedaSencilla() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "aumentar lograr",
				"Analizador_Noticia", "fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 2);

	}

	// Búsqueda normal por palabras. Busco en el cuerpo il dottore.
	@Test
	public void test3BusquedaSencilla() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "il dottore", "Analizador_Noticia",
				"fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 1);

	}

	// Búsqueda por Autor. Busco Martínez Páez (no me preocupo de los acentos, porque al pasarle
	// el "Analizador_Noticia" Hibernate Search se encarga de preparar las palabras de manera correcta.
	@Test
	public void test4BusquedaPorAutor() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "Martínez Páez",
				"Analizador_Noticia", "fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 1);

	}

	// Busco palabras que no debe de haber indexado.
	@Test
	public void test5BusquedaStopWord() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "éste esta este algunos alguna",
				"Analizador_Noticia", "fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 0);

	}

	// Busco palabras que no debe de haber indexado.
	@Test
	public void test6BusquedaHTML() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "<div> href <p>",
				"Analizador_Noticia", "fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 0);

	}

	// Busco por rango de fechas. [20080101 TO 20101231]
	// Desde el 1 de enero de 2008 hasta el 31 de diciembre de 2010.
	@Test
	public void test7BusquedaFechas() {
		HibernateDaoImpl dao = DaoFactory.getDao();

		List<Noticia> noticias = dao.findByFullText(Noticia.class, whereToSearch, "[20080101 TO 20101231]",
				"Analizador_Noticia", "fechaPublicacion");

		Assert.assertTrue("El número de noticias encontradas no coincide", noticias.size() == 3);

	}
}
