package com.autentia.adictos.hs.test.utils;

import java.io.FileReader;
import java.io.IOException;
import java.util.Date;

import com.autentia.adictos.hs.dao.DaoFactory;
import com.autentia.adictos.hs.dao.HibernateDaoImpl;
import com.autentia.adictos.hs.model.Autor;
import com.autentia.adictos.hs.model.Noticia;

/**
 * Clase para creación de datos de pruebas
 * 
 * @author fjmpaez
 */
public class DataGenerator {

	public static void createData() {
		/*
		 * Inicializamos la factoría de sesiones de Hibernate
		 */
		HibernateDaoImpl dao = DaoFactory.getDao();

		Autor autor1 = new Autor();
		autor1.setNombre("Francisco Javier");
		autor1.setApellidos("Martínez");
		dao.persist(autor1);

		Autor autor2 = new Autor();
		autor2.setNombre("Roberto");
		autor2.setApellidos("Canales Mora");
		dao.persist(autor2);

		Autor autor3 = new Autor();
		autor3.setNombre("Juan");
		autor3.setApellidos("Alonso Ramos");
		dao.persist(autor3);

		Noticia noticia1 = new Noticia();
		noticia1.setTitular("Alberto Contador casi sentencia el Tour");
		noticia1.setEntradilla("El ciclista español logró pulverizar "
				+ "todos los registros en la crono y consigue su doblete en este "
				+ "Tour de Francia ampliando diferencias con todos sus rivales. "
				+ "Lance Armstrong vuelve al podio, donde ahora es tercero, pero a sólo a 11 segundos de Wiggins");
		noticia1.setFechaPublicacion(new Date());
		noticia1.setAutor(autor1);
		noticia1.setCuerpo(readBody("cuerpo1.html"));

		dao.persist(noticia1);

		Noticia noticia2 = new Noticia();
		noticia2.setTitular("Aumenta la tensión entre Lorenzo y Rossi");
		noticia2.setEntradilla("Jorge Lorenzo no entiende las duras críticas de Valentino Rossi en Alemania. "
				+ "Ve posible renovar con Yamaha, pero admite tener otras ofertas");
		noticia2.setFechaPublicacion(new Date());
		noticia2.setAutor(autor2);
		noticia2.setCuerpo(readBody("cuerpo2.html"));

		dao.persist(noticia2);

		Noticia noticia3 = new Noticia();
		noticia3.setTitular("Alonso: Queremos intentar confirmar que el coche ha mejorado");
		noticia3.setEntradilla("Queremos intentar confirmar que el coche ha mejorado, "
				+ "que podemos estar en niveles competitivos y que las vueltas rápidas de Nurburgring "
				+ "no fueron producto de las temperaturas bajas o cualquier otro motivo raro");
		noticia3.setFechaPublicacion(new Date());
		noticia3.setAutor(autor3);
		noticia3.setCuerpo(readBody("cuerpo3.html"));

		dao.persist(noticia3);

	}

	/**
	 * Lee el texto del fichero y lo devuelve
	 * 
	 * @param fileName
	 * @return
	 */
	private static String readBody(String fileName) {

		StringBuilder sb = new StringBuilder();
		FileReader fr = null;
		try {
			fr = new FileReader(DataGenerator.class.getClassLoader().getResource(fileName).getPath());

			char[] c = new char[256];
			int cars = fr.read(c);
			while (cars != -1) {
				sb.append(c);
				cars = fr.read(c);
			}
			return sb.toString();
		} catch (Exception e) {
			e.printStackTrace();
			return "";
		} finally {
			if (fr != null) {
				try {
					fr.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}

	}

}
